function startFullScreen(element) {
  if (element.requestFullscreen) {
    element.requestFullscreen();
  } else if (element.mozRequestFullScreen) {
    element.mozRequestFullScreen();
  } else if (element.webkitRequestFullscreen) {
    element.webkitRequestFullscreen();
  } else if (element.msRequestFullscreen) {
    element.msRequestFullscreen();
  }
}

function cancelFullScreen(element) {
  if (document.exitFullscreen) {
    document.exitFullscreen();
  } else if (document.mozCancelFullScreen) {
    document.mozCancelFullScreen();
  } else if (document.webkitCancelFullScreen) {
    document.webkitCancelFullScreen();
  } else if (document.msExitFullscreen) {
    document.msExitFullscreen();
  }
}

function toggleFullScreen(element) {
  var isInFullScreen = (document.fullscreenElement && document.fullscreenElement !== null) ||
        (document.webkitFullscreenElement && document.webkitFullscreenElement !== null) ||
        (document.mozFullScreenElement && document.mozFullScreenElement !== null) ||
        (document.msFullscreenElement && document.msFullscreenElement !== null);
  if (!isInFullScreen) {
    startFullScreen(element);
  } else {
    cancelFullScreen();
  }
}

function getStatus() {
  var xhttp = new XMLHttpRequest();
  xhttp.onreadystatechange = function() {
    if (xhttp.readyState === 4) {
      var backgroundModeStart = document.getElementById("backgroundModeStart");
      var backgroundModeStop = document.getElementById("backgroundModeStop");
      var backgroundModeStatus = document.getElementById("backgroundModeStatus");
      var cpuUsagePercentage = document.getElementById("cpuUsagePercentage");
      var liveConnections = document.getElementById("liveConnections");
      var battery = document.getElementById("battery");
      var memoryUsed = document.getElementById("memoryUsed");
      var threadsUsed = document.getElementById("threadsUsed");
      var threadsRunnableUsed = document.getElementById("threadsRunnableUsed");
      var processes = document.getElementById("processes");
      var uptime = document.getElementById("uptime");
      var networkIn = document.getElementById("networkIn");
      var networkOut = document.getElementById("networkOut");
      var recorded = document.getElementById("recorded");
      var available = document.getElementById("available");
      var lowBandwidthProfile = document.getElementById("lowBandwidthProfile");
      var powerSafeMode = document.getElementById("powerSafeMode");
      var notifications = document.getElementById("notifications");
      var notificationsWarning = document.getElementById("notificationsWarning");
      if (xhttp.status === 200) {
        var json = JSON.parse(xhttp.responseText);
        var backgroundMode = json.backgroundMode;
        backgroundModeStart.disabled = backgroundMode;
        backgroundModeStop.disabled = !backgroundMode;
        backgroundModeStatus.textContent = (backgroundMode ? "Started" : "Stopped");
        cpuUsagePercentage.textContent = json.cpuUsagePercentage;
        liveConnections.textContent = json.liveConnections;
        battery.textContent = json.battery;
        uptime.textContent = json.uptime;
        networkIn.textContent = json.networkIn;
        networkOut.textContent = json.networkOut;
        recorded.textContent = json.recorded;
        available.textContent = json.available;
        if (memoryUsed != null)
          memoryUsed.textContent = json.memoryUsed;
        if (threadsUsed != null)
          threadsUsed.textContent = json.threadsUsed;
        if (threadsRunnableUsed != null)
          threadsRunnableUsed.textContent = json.threadsRunnableUsed;
        if (processes != null)
          processes.textContent = json.processes;
        cpuSeries.append(new Date().getTime(), json.cpuUsagePercentage);
        lowBandwidthProfile.selectedIndex = json.lowBandwidthProfile;
        powerSafeMode.selectedIndex = json.powerSafeMode;
        notifications.selectedIndex = json.notifications;
        notificationsWarning.style.display = (json.notifications == 1 ? 'none' : 'block');
        setTimeout(getStatus, 2500);
      } else {
        console.warn('tinyCam web server is not responding. Retry in 10 sec.');
        // temperature.style.visibility = "hidden";
        backgroundModeStart.disabled = true;
        backgroundModeStop.disabled = true;
        backgroundModeStatus.textContent = "-";
        cpuUsagePercentage.textContent = "-";
        liveConnections.textContent = "-";
        battery.textContent = "-";
        uptime.textContent = "-";
        networkIn.textContent = "-";
        networkOut.textContent = "-";
        recorded.textContent = "-";
        available.textContent = "-";
        if (memoryUsed != null)
          memoryUsed.textContent = "-";
        if (threadsUsed != null)
          threadsUsed.textContent = "-";
        if (threadsRunnableUsed != null)
          threadsRunnableUsed.textContent = "-";
        if (processes != null)
          processes.textContent = "-";
        cpuSeries.append(new Date().getTime(), -1);
        lowBandwidthProfile.selectedIndex = -1;
        powerSafeMode.selectedIndex = -1;
        notifications.selectedIndex = -1;
        notificationsWarning.style.display = 'none';
        setTimeout(getStatus, 10000);
      }
    }
  };
  xhttp.open("GET", "status.json", true);
  xhttp.send();
}

function fitToContainerWidth(canvas) {
  canvas.style.width='100%';
  canvas.width = canvas.offsetWidth;
}

function sendHttpGetAsync(request) {
  var xhttp = new XMLHttpRequest();
  xhttp.open("GET", request, true);
  xhttp.send();
}
